@@ -105,7 +105,7 @@ class Review(CloneMixin, ComplexToStringMixin, WBModel):
                 WBColor.GREEN_LIGHT.value,
                 WBColor.GREEN_DARK.value,
             ]
-            return [choice for choice in zip(cls, colors)]
+            return [choice for choice in zip(cls, colors, strict=False)]
 
     class Type(models.TextChoices):
         ANNUAL = "ANNUAL", _("Annual")
@@ -721,6 +721,9 @@ class ReviewAnswer(models.Model):
     )
     answer_text = models.TextField(null=True, blank=True, verbose_name=_("Comment"))
 
+    def __str__(self) -> str:
+        return f"{self.question} - {self.answered_by}"
+
     @classmethod
     def get_endpoint_basename(cls):
         return "wbhuman_resources:reviewanswer"
