@@ -303,24 +303,24 @@ class ReviewQuestionReviewDisplayConfig(ReviewQuestionDisplayConfig):
 
 class ReviewAnswerDisplayConfig(DisplayViewConfig):
     def get_list_display(self) -> Optional[dp.ListDisplay]:
-        FIELDS = [
+        fields = [
             dp.Field(key="question_name", label=_("Question"), width=Unit.PIXEL(720)),
             dp.Field(key="mandatory", label=_("Mandatory"), width=Unit.PIXEL(80)),
         ]
         if self.view.get_queryset().filter(question__answer_type=ReviewQuestion.ANSWERTYPE.RATING):
-            FIELDS += [dp.Field(key="answer_number", label=_("Rating"), width=Unit.PIXEL(170))]
+            fields += [dp.Field(key="answer_number", label=_("Rating"), width=Unit.PIXEL(170))]
 
-        FIELDS += [dp.Field(key="answer_text", label=_("Comment"), width=Unit.PIXEL(720))]
+        fields += [dp.Field(key="answer_text", label=_("Comment"), width=Unit.PIXEL(720))]
 
         if review_id := self.view.kwargs.get("review_id"):
             review = Review.objects.get(id=review_id)
             if review.status in [Review.Status.EVALUATION, Review.Status.VALIDATION]:
-                FIELDS = [
+                fields = [
                     dp.Field(key="question_name", label=_("Question"), width=Unit.PIXEL(740)),
                     dp.Field(key="answered_by", label=_("Answered By"), width=Unit.PIXEL(140)),
                     dp.Field(key="answer_text", label=_("Comment"), width=Unit.PIXEL(740)),
                 ]
-        return dp.ListDisplay(fields=FIELDS)
+        return dp.ListDisplay(fields=fields)
 
     def get_instance_display(self) -> Display:
         grid_fields = [[repeat_field(2, "question_name")], ["mandatory", "."]]
